@@ -6,12 +6,12 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 use teloxide::types::ChatId;
 
 use crate::{error::Result, settings, sink};
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize, Serialize, Debug)]
 #[serde(deny_unknown_fields)]
 pub(crate) struct Telegram {
 	chat_id: ChatId,
@@ -19,6 +19,10 @@ pub(crate) struct Telegram {
 
 impl Telegram {
 	pub(crate) fn parse(self) -> Result<sink::Telegram> {
-		Ok(sink::Telegram::new(settings::telegram()?, self.chat_id))
+		let chat_id = match std::env::var("FETCHER_DEBUG_CHAT_ID") {
+			Ok(s) => ChatId::try_from(s).expect("Invalid chat id in FETCHER_DEBUG_CHAT_ID"),
+			_ => self.chat_id,
+		};
+		Ok(sink::Telegram::new(settings::telegram()?, chat_id))
 	}
 }
