@@ -6,11 +6,11 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 
 use crate::source;
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize, Serialize, Debug)]
 #[serde(rename_all = "snake_case", deny_unknown_fields)]
 pub(crate) enum ViewMode {
 	ReadOnly,
@@ -20,7 +20,7 @@ pub(crate) enum ViewMode {
 
 impl ViewMode {
 	pub(crate) fn parse(self) -> source::email::ViewMode {
-		use ViewMode::*;
+		use ViewMode::{Delete, MarkAsRead, ReadOnly};
 
 		match self {
 			ReadOnly => source::email::ViewMode::ReadOnly,
