@@ -6,11 +6,11 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 
 use crate::{error::Result, settings, source};
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize, Serialize, Debug)]
 #[serde(deny_unknown_fields)]
 pub(crate) struct Twitter {
 	pretty_name: String,
@@ -22,12 +22,12 @@ impl Twitter {
 	pub(crate) fn parse(self) -> Result<source::Twitter> {
 		let (api_key, api_secret) = settings::twitter()?;
 
-		source::Twitter::new(
+		Ok(source::Twitter::new(
 			self.pretty_name,
 			self.handle,
 			api_key,
 			api_secret,
 			self.filter,
-		)
+		))
 	}
 }
