@@ -5,11 +5,15 @@
  *
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
+#![warn(clippy::pedantic)]
+#![allow(clippy::missing_panics_doc)] // TODO
+#![allow(clippy::missing_errors_doc)]
 
 // TODO: more tests
 
 pub mod auth;
 pub mod config;
+pub mod entry;
 pub mod error;
 pub mod read_filter;
 pub mod settings;
@@ -23,20 +27,30 @@ use tokio::time::sleep;
 use crate::error::Error;
 use crate::error::Result;
 use crate::read_filter::ReadFilter;
+use crate::source::Source;
 use crate::task::Task;
 
-#[tracing::instrument(skip(t))]
 pub async fn run_task(name: &str, t: &mut Task) -> Result<()> {
-	let mut read_filter = ReadFilter::read_from_fs(name, t.read_filter_kind)?;
+	let mut read_filter = t
+		.read_filter_kind
+		.map(|x| ReadFilter::read_from_fs(name.to_owned(), x))
+		.transpose()?;
+
 	loop {
-		tracing::debug!("Fetching");
+		tracing::trace!("Running...");
 
 		let fetch = async {
-			for rspn in t.source.get(&read_filter).await? {
-				t.sink.send(rspn.msg).await?;
+			for entry in t.source.get(read_filter.as_ref()).await? {
+				tracing::trace!("Processing entry: {entry:?}");
 
-				if let Some(id) = rspn.id {
-					read_filter.mark_as_read(&id)?;
+				t.sink.send(entry.msg).await?;
+				match (&mut t.source, &mut read_filter) {
+					// Email has custom read filtering and read marking
+					(Source::Email(e), None) => e.mark_as_read(&entry.id).await?,
+					// delete read_filter save file if it was created for some very strange reason for this source type
+					(Source::Email(_), Some(_)) => read_filter.take().unwrap().delete_from_fs()?,
+					(_, Some(f)) => f.mark_as_read(&entry.id)?,
+					_ => unreachable!(),
 				}
 			}
 
@@ -45,7 +59,7 @@ pub async fn run_task(name: &str, t: &mut Task) -> Result<()> {
 
 		match fetch.await {
 			Ok(_) => (),
-			Err(e @ Error::Network(_)) => tracing::warn!("{e:?}"),
+			Err(e @ Error::Network(_)) => tracing::warn!("{:?}", anyhow::anyhow!(e)),
 			Err(e) => return Err(e),
 		}
 
