@@ -27,8 +27,13 @@ fn read_filter_path(name: &str) -> Result<PathBuf> {
 	})
 }
 
-pub fn read_filter(name: &str) -> Result<Option<ReadFilter>> {
-	let path = read_filter_path(name)?;
+/// Returns a read filter for the task name from the filesystem.
+///
+/// # Errors
+/// * if the file is inaccessible
+/// * if the file is corrupted
+pub fn get(name: String) -> Result<Option<ReadFilter>> {
+	let path = read_filter_path(&name)?;
 	fs::read_to_string(&path)
 		.ok()
 		.map(|s| {
@@ -41,20 +46,27 @@ pub fn read_filter(name: &str) -> Result<Option<ReadFilter>> {
 
 /// Save the provided read filter to the fs or remove it from the fs if it's empty
 ///
-/// # Errors if
-/// * the default read filter save file path is inaccessible
-/// * the write failed
-/// * the remove failed
-pub fn save_read_filter(read_filter: &ReadFilter) -> Result<()> {
-	let path = read_filter_path(&read_filter.name)?;
-	// fs::write(&path, id).map_err(|e| Error::Write(e, path))
+/// # Errors
+/// * if the default read filter save file path is inaccessible
+/// * if the write failed
+/// * if the remove failed
+#[allow(clippy::missing_panics_doc)]
+pub fn save(filter: &ReadFilter) -> Result<()> {
+	let path = read_filter_path(filter.name())?;
+	let filter_conf = config::read_filter::ReadFilter::unparse(filter);
 
-	let read_filter_conf = config::read_filter::ReadFilter::unparse(&read_filter.inner);
-	match read_filter_conf {
+	match filter_conf {
 		Some(data) => {
 			fs::write(&path, serde_json::to_string(&data).unwrap()) // unwrap NOTE: safe, serialization of such a simple struct should never fail
 				.map_err(|e| Error::Write(e, path))
 		}
-		None => fs::remove_file(&path).map_err(|e| Error::Write(e, path)),
+		None => delete(filter),
 	}
 }
+
+pub fn delete(filter: &ReadFilter) -> Result<()> {
+	let path = read_filter_path(filter.name())?;
+
+	// TODO: don't error if file doesn't exist
+	fs::remove_file(&path).map_err(|e| Error::Write(e, path))
+}
